@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 from collections import namedtuple
-from datetime import datetime, date
+from datetime import datetime, timedelta
 from json import loads
-from lxml import html, etree
+from lxml import html
 from re import search
 import logging
 
@@ -65,22 +65,6 @@ class Messager(object):
         return MessageInfo(response_dict.get('threadid'), response_dict['msgid'])
 
 
-def get_additional_info(tree):
-    age = int(xpb.span(id='ajax_age').get_text_(tree).strip())
-    orientation = tree.xpath("//*[@id = 'ajax_orientation']/text()")[0].strip()
-    status = tree.xpath("//*[@id = 'ajax_status']/text()")[0].strip()
-    gender_result = tree.xpath("//*[@id = 'ajax_gender']/text()")[0].strip()
-    location = tree.xpath("//*[@id = 'ajax_location']/text()")[0].strip()
-    if gender_result == "M":
-        gender = 'Male'
-    elif gender_result == "F":
-        gender = 'Female'
-    return age, gender, orientation, status, location
-
-
-utf8_parser = etree.XMLParser(encoding='utf-8')
-
-
 @util.n_partialable
 def get_js_variable(html_response, variable_name):
     script_elements = xpb.script.apply_(html_response)
@@ -96,18 +80,84 @@ get_current_user_id = get_id
 get_my_username = get_username
 
 
+weekday_to_ordinal = {
+    'monday': 0,
+    'tuesday': 1,
+    'wednesday': 2,
+    'thursday': 3,
+    'friday': 4,
+    'saturday': 5,
+    'sunday': 6
+}
+
+
 def parse_date_updated(date_updated_text):
-    if '/' in date_updated_text:
-        return datetime.strptime(date_updated_text, '%m/%d/%y').date()
+    recognized = False
+    for function in (parse_slashed_date, parse_abbreviated_date,
+                     parse_time, parse_day_of_the_week):
+        parsed_time = function(date_updated_text)
+        if parsed_time is not None:
+            recognized = True
+            break
+    else:
+        parsed_time = datetime.today()
+    log_function = log.info if recognized else log.error
+    log_function(simplejson.dumps({"incoming_date": date_updated_text,
+                                   "outgoing_date": parsed_time.strftime("%Y.%m.%d %H:%M"),
+                                   "recognized": recognized}))
+    return parsed_time
 
-    if date_updated_text[-2] == ' ':
-        month, day = date_updated_text.split()
-        date_updated_text = '{0} 0{1}'.format(month, day)
 
+def parse_slashed_date(date_updated_text):
     try:
-        return datetime.strptime(date_updated_text, '%b %d').replace(year=datetime.now().year).date()
+        return datetime.strptime(date_updated_text, '%m/%d/%y')
     except:
-        return date.today()
+        pass
+
+def parse_abbreviated_date(date_updated_text):
+    try:
+        parsed_time = datetime.strptime(date_updated_text, '%b %d')
+    except:
+        pass
+    else:
+        return parsed_time.replace(year=datetime.now().year)
+
+def parse_time(date_updated_text):
+    try:
+        time = datetime.strptime(date_updated_text, '%I:%M%p')
+    except:
+        pass
+    else:
+        today = datetime.today()
+        parsed_time = time.replace(year=today.year, day=today.day,
+                                   month=today.month)
+        if parsed_time > datetime.now():
+            parsed_time = parsed_time - timedelta(days=1)
+        return parsed_time
+
+
+def parse_day_of_the_week(date_updated_text):
+    try:
+        datetime.strptime(date_updated_text, '%A')
+    except:
+        pass
+    else:
+        return date_from_weekday(date_updated_text)
+
+
+def date_from_weekday(weekday):
+    today = datetime.now()
+    incoming_weekday_ordinal = weekday_to_ordinal[weekday.lower()]
+    today_ordinal = today.weekday()
+    difference = (today_ordinal - incoming_weekday_ordinal
+                  if today_ordinal > incoming_weekday_ordinal else
+                  7 - incoming_weekday_ordinal + today_ordinal)
+    return today - timedelta(days=difference)
+
+
+def datetime_to_string(a_datetime):
+    if a_datetime:
+        return a_datetime.strftime('%H:%M:%S')
 
 
 def get_locid(session, location):
