@@ -26,14 +26,18 @@ class n_partialable(object):
         function_info = inspect.getargspec(function)
         function_args = function_info.args
         if is_class:
-            # This is to handle the fact that self will get passed in automatically.
+            # This is to handle the fact that self will get passed in
+            # automatically.
             function_args = function_args[1:]
         def evaluation_checker(*args, **kwargs):
             kwarg_keys = set(kwargs.keys())
             if function_info.keywords == None:
                 acceptable_kwargs = function_args[len(args):]
                 # Make sure that we didn't get an argument we can't handle.
-                assert kwarg_keys.issubset(acceptable_kwargs)
+                try:
+                    assert kwarg_keys.issubset(acceptable_kwargs)
+                except:
+                    import ipdb; ipdb.set_trace()
             needed_args = function_args[len(args):]
             if function_info.defaults:
                 needed_args = needed_args[:-len(function_info.defaults)]
@@ -104,6 +108,10 @@ class cached_property(object):
         setattr(obj, self.func.__name__, value)
         return value
 
+    def bust_self(self, obj):
+        if self.func.__name__ in obj.__dict__:
+            delattr(obj, self.func.__name__)
+
     @classmethod
     def bust_caches(cls, obj):
         for name, _ in cls.get_cached_properties(obj):
@@ -176,7 +184,8 @@ def add_command_line_options(add_argument, use_short_options=True):
         logger_args += ('-l',)
         credentials_args += ('-c',)
     add_argument(*logger_args, dest='enabled_loggers',
-                 action="append", default=[], help="Enable the specified logger.")
+                 action="append", default=[],
+                 help="Enable the specified logger.")
     add_argument(*credentials_args, dest='credentials_modules',
                  action="append", default=[],
                  help="Use the specified credentials module to update "
@@ -193,7 +202,7 @@ def handle_command_line_options(args):
     if args.echo:
         from okcupyd import db
         db.echo = True
-        db.Session.kw['echo'] = True
+        db.Session.kw['bind'].echo = True
     return args
 
 
@@ -216,25 +225,120 @@ def save_file(filename, data):
 
 class Fetchable(object):
 
-    def __init__(self, fetcher):
+    def __init__(self, fetcher, **kwargs):
         self._fetcher = fetcher
+        self._kwargs = kwargs
+        self.refresh()
 
-    @cached_property
-    def items(self):
-        return list(self._fetcher.fetch())
+    def refresh(self, nice_repr=True, **kwargs):
+        for key, value in self._kwargs.items():
+            kwargs.setdefault(key, value)
+        # No real good reason to hold on to this. DONT TOUCH.
+        self._original_iterable = self._fetcher.fetch(**kwargs)
+        self.exhausted = False
+        if nice_repr:
+            self._accumulated = []
+            self._original_iterable = self._make_nice_repr_iterator(
+                self._original_iterable, self._accumulated
+            )
+        else:
+            self._accumulated = None
+        self._clonable, = itertools.tee(self._original_iterable, 1)
+        return self
 
-    def refresh(self, use_existing=False, stop_at=None):
-        if 'items' in self.__dict__:
-            self.items = list(self._fetcher.fetch(
-                id_to_existing=self.items if use_existing else ()
-            ))
-        return self.items
+    @staticmethod
+    def _make_nice_repr_iterator(original_iterable, accumulator):
+        for item in original_iterable:
+            accumulator.append(item)
+            yield item
+
+    __call__ = refresh
 
     def __iter__(self):
-        return iter(self.items)
+        # This is hard to think about, but you can't ever use an iterator
+        # if you plan on cloning it. Furthermore, you can only clone it once
+        # (directly). For this reason, we throw away the iterator once it has
+        # been cloned.
+        new_iterable, self._clonable = itertools.tee(self._clonable, 2)
+        return new_iterable
 
     def __getitem__(self, item):
-        return self.items[item]
+        iterator = iter(self)
+
+        if not isinstance(item, slice):
+            assert isinstance(item, int)
+            if item < 0:
+                return list(iterator)[item]
+            try:
+                for i in range(item):
+                    next(iterator)
+                return next(iterator)
+            except StopIteration:
+                self.exhausted = True
+                raise IndexError("The Fetchable does not have a value at the "
+                                 "index that was provided.")
+
+        # We have a slice
+        if item.start is None and item.stop is None:
+            # No point in being lazy if they want it all.
+            self.exhausted = True
+            return list(iterator)[item]
+        if ((item.start and item.start < 0) or
+            (not item.stop or item.stop < 0)):
+            # If we have any negative numbers we have to expand the whole
+            # thing anyway. This is also the case if there is no bound
+            # on the slice, hence the `not item.stop` trigger.
+            self.exausted = True
+            return list(iterator)[item]
+        accumulator = []
+        # No need to do this for stop since we are sure it is not None.
+        start = item.start or 0
+        for _ in range(start):
+            try:
+                next(iterator)
+            except StopIteration: # This is strange but its what list do.
+                self.exhausted = True
+                break
+        for i in range(item.stop - start):
+            try:
+                value = next(iterator)
+            except StopIteration:
+                self.exhausted = True
+                break
+            else:
+                if item.step == None or i % item.step == 0:
+                    accumulator.append(value)
+        return accumulator
+
+    def __repr__(self):
+        if self._accumulated == None:
+            list_repr = ''
+        else:
+            list_repr = repr(self._accumulated)
+            if not self.exhausted:
+                if len(self._accumulated) == 0:
+                    list_repr = '[...]'
+                else:
+                    list_repr = '{0}, ...]'.format(list_repr[:-1])
+        return '{0}({1}){2}'.format(type(self).__name__,
+                                    repr(self._fetcher), list_repr)
+
+    def __len__(self):
+        return len(self[:])
+
+    def __add__(self, other):
+        return self[:] + other[:]
+
+    def __eq__(self, other):
+        return self[:] == other[:]
+
+    def __nonzero__(self):
+        try:
+            self[0]
+        except IndexError:
+            return False
+        else:
+            return True
 
 
 class StepObjectFetcher(object):
@@ -251,12 +355,11 @@ class StepObjectFetcher(object):
         start_at_iterator = (range(start_at + 1, get_at_least + 1, self.step)
                              if get_at_least
                              else itertools.count(start_at + 1, self.step))
-        generators = []
         for start_at in start_at_iterator:
             text_response = self._fetcher.fetch(start_at)
             if not text_response: break
-            generators.append(self._processor.process(text_response))
-        return itertools.chain(*generators)
+            for i in self._processor.process(text_response):
+                yield i
 
 
 def find_all(a_str, sub):
