@@ -17,7 +17,7 @@ def test_handle_no_pictures():
 @util.use_cassette(cassette_name='user_get_threads')
 def test_get_inbox():
     user = User()
-    assert len(user.inbox.items) == 1
+    assert len(user.inbox) == 1
 
     for message_thread in user.inbox:
         for message in message_thread.messages:
@@ -96,4 +96,4 @@ def test_profile_titles():
 def test_user_profile_attributes():
     user_profile = User().profile
     assert user_profile.id > 0
-    assert user_profile.rating == 0
\ No newline at end of file
+    assert user_profile.rating == 0
